@@ -200,6 +200,54 @@ static const struct asn1_oid rose_etsi_ect = {
 /* *INDENT-ON* */
 };
 
+/*! \brief ETSI Status Request OID prefix. */
+static const struct asn1_oid rose_etsi_status_request = {
+/* *INDENT-OFF* */
+	/* {itu-t(0) identified-organization(4) etsi(0) 196 status-request-procedure(9)} */
+	4, { 4, 0, 196, 9 }
+/* *INDENT-ON* */
+};
+
+/*! \brief ETSI Call Completion Busy Status OID prefix. */
+static const struct asn1_oid rose_etsi_ccbs = {
+/* *INDENT-OFF* */
+	/* {ccitt(0) identified-organization(4) etsi(0) 359 operations-and-errors(1)} */
+	4, { 4, 0, 359, 1 }
+/* *INDENT-ON* */
+};
+
+/*! \brief ETSI Call Completion Busy Status public-private interworking OID prefix. */
+static const struct asn1_oid rose_etsi_ccbs_t = {
+/* *INDENT-OFF* */
+	/* {ccitt(0) identified-organization(4) etsi(0) 359 private-networks-operations-and-errors(2)} */
+	4, { 4, 0, 359, 2 }
+/* *INDENT-ON* */
+};
+
+/*! \brief ETSI Call Completion No Reply OID prefix. */
+static const struct asn1_oid rose_etsi_ccnr = {
+/* *INDENT-OFF* */
+	/* {ccitt(0) identified-organization(4) etsi(0) 1065 operations-and-errors(1)} */
+	4, { 4, 0, 1065, 1 }
+/* *INDENT-ON* */
+};
+
+/*! \brief ETSI Call Completion No Reply public-private interworking OID prefix. */
+static const struct asn1_oid rose_etsi_ccnr_t = {
+/* *INDENT-OFF* */
+	/* {ccitt(0) identified-organization(4) etsi(0) 1065 private-networks-operations-and-errors(2)} */
+	4, { 4, 0, 1065, 2 }
+/* *INDENT-ON* */
+};
+
+/*! \brief ETSI Message Waiting Indication OID prefix. */
+static const struct asn1_oid rose_etsi_mwi = {
+/* *INDENT-OFF* */
+	/* {ccitt(0) identified-organization(4) etsi(0) 745 operations-and-errors(1)} */
+	4, { 4, 0, 745, 1 }
+/* *INDENT-ON* */
+};
+
 /*! \brief ETSI specific invoke/result encode/decode message table */
 static const struct rose_convert_msg rose_etsi_msgs[] = {
 /* *INDENT-OFF* */
@@ -361,6 +409,166 @@ static const struct rose_convert_msg rose_etsi_msgs[] = {
 			rose_enc_etsi_EctLoopTest_ARG,			rose_enc_etsi_EctLoopTest_RES,
 			rose_dec_etsi_EctLoopTest_ARG,			rose_dec_etsi_EctLoopTest_RES
 	},
+
+	/*
+	 * globalValue's (OIDs) from Status-Request-Procedure
+	 * {itu-t identified-organization etsi(0) 196 status-request-procedure(9)}
+	 */
+	{
+		ROSE_ETSI_StatusRequest,					&rose_etsi_status_request, 1,
+			rose_enc_etsi_StatusRequest_ARG,		rose_enc_etsi_StatusRequest_RES,
+			rose_dec_etsi_StatusRequest_ARG,		rose_dec_etsi_StatusRequest_RES
+	},
+
+	/*
+	 * globalValue's (OIDs) from CCBS-Operations-and-Errors
+	 * {ccitt identified-organization etsi(0) 359 operations-and-errors(1)}
+	 */
+	{
+		ROSE_ETSI_CallInfoRetain,					&rose_etsi_ccbs, 1,
+			rose_enc_etsi_CallInfoRetain_ARG,		NULL,
+			rose_dec_etsi_CallInfoRetain_ARG,		NULL
+	},
+	{
+		ROSE_ETSI_CCBSRequest,						&rose_etsi_ccbs, 2,
+			rose_enc_etsi_CCBSRequest_ARG,			rose_enc_etsi_CCBSRequest_RES,
+			rose_dec_etsi_CCBSRequest_ARG,			rose_dec_etsi_CCBSRequest_RES
+	},
+	{
+		ROSE_ETSI_CCBSDeactivate,					&rose_etsi_ccbs, 3,
+			rose_enc_etsi_CCBSDeactivate_ARG,		NULL,
+			rose_dec_etsi_CCBSDeactivate_ARG,		NULL
+	},
+	{
+		ROSE_ETSI_CCBSInterrogate,					&rose_etsi_ccbs, 4,
+			rose_enc_etsi_CCBSInterrogate_ARG,		rose_enc_etsi_CCBSInterrogate_RES,
+			rose_dec_etsi_CCBSInterrogate_ARG,		rose_dec_etsi_CCBSInterrogate_RES
+	},
+	{
+		ROSE_ETSI_CCBSErase,						&rose_etsi_ccbs, 5,
+			rose_enc_etsi_CCBSErase_ARG,			NULL,
+			rose_dec_etsi_CCBSErase_ARG,			NULL
+	},
+	{
+		ROSE_ETSI_CCBSRemoteUserFree,				&rose_etsi_ccbs, 6,
+			rose_enc_etsi_CCBSRemoteUserFree_ARG,	NULL,
+			rose_dec_etsi_CCBSRemoteUserFree_ARG,	NULL
+	},
+	{
+		ROSE_ETSI_CCBSCall,							&rose_etsi_ccbs, 7,
+			rose_enc_etsi_CCBSCall_ARG,				NULL,
+			rose_dec_etsi_CCBSCall_ARG,				NULL
+	},
+	{
+		ROSE_ETSI_CCBSStatusRequest,				&rose_etsi_ccbs, 8,
+			rose_enc_etsi_CCBSStatusRequest_ARG,	rose_enc_etsi_CCBSStatusRequest_RES,
+			rose_dec_etsi_CCBSStatusRequest_ARG,	rose_dec_etsi_CCBSStatusRequest_RES
+	},
+	{
+		ROSE_ETSI_CCBSBFree,						&rose_etsi_ccbs, 9,
+			rose_enc_etsi_CCBSBFree_ARG,			NULL,
+			rose_dec_etsi_CCBSBFree_ARG,			NULL
+	},
+	{
+		ROSE_ETSI_EraseCallLinkageID,				&rose_etsi_ccbs, 10,
+			rose_enc_etsi_EraseCallLinkageID_ARG,	NULL,
+			rose_dec_etsi_EraseCallLinkageID_ARG,	NULL
+	},
+	{
+		ROSE_ETSI_CCBSStopAlerting,					&rose_etsi_ccbs, 11,
+			rose_enc_etsi_CCBSStopAlerting_ARG,		NULL,
+			rose_dec_etsi_CCBSStopAlerting_ARG,		NULL
+	},
+
+	/*
+	 * globalValue's (OIDs) from CCBS-private-networks-Operations-and-Errors
+	 * {ccitt identified-organization etsi(0) 359 private-networks-operations-and-errors(2)}
+	 */
+	{
+		ROSE_ETSI_CCBS_T_Request,					&rose_etsi_ccbs_t, 1,
+			rose_enc_etsi_CCBS_T_Request_ARG,		rose_enc_etsi_CCBS_T_Request_RES,
+			rose_dec_etsi_CCBS_T_Request_ARG,		rose_dec_etsi_CCBS_T_Request_RES
+	},
+	{
+		ROSE_ETSI_CCBS_T_Call,						&rose_etsi_ccbs_t, 2,
+			NULL,									NULL,
+			NULL,									NULL
+	},
+	{
+		ROSE_ETSI_CCBS_T_Suspend,					&rose_etsi_ccbs_t, 3,
+			NULL,									NULL,
+			NULL,									NULL
+	},
+	{
+		ROSE_ETSI_CCBS_T_Resume,					&rose_etsi_ccbs_t, 4,
+			NULL,									NULL,
+			NULL,									NULL
+	},
+	{
+		ROSE_ETSI_CCBS_T_RemoteUserFree,			&rose_etsi_ccbs_t, 5,
+			NULL,									NULL,
+			NULL,									NULL
+	},
+	{
+		ROSE_ETSI_CCBS_T_Available,					&rose_etsi_ccbs_t, 6,
+			NULL,									NULL,
+			NULL,									NULL
+	},
+
+	/*
+	 * globalValue's (OIDs) from CCNR-Operations-and-Errors
+	 * {ccitt identified-organization etsi(0) 1065 operations-and-errors(1)}
+	 */
+	{
+		ROSE_ETSI_CCNRRequest,						&rose_etsi_ccnr, 1,
+			rose_enc_etsi_CCNRRequest_ARG,			rose_enc_etsi_CCNRRequest_RES,
+			rose_dec_etsi_CCNRRequest_ARG,			rose_dec_etsi_CCNRRequest_RES
+	},
+	{
+		ROSE_ETSI_CCNRInterrogate,					&rose_etsi_ccnr, 2,
+			rose_enc_etsi_CCNRInterrogate_ARG,		rose_enc_etsi_CCNRInterrogate_RES,
+			rose_dec_etsi_CCNRInterrogate_ARG,		rose_dec_etsi_CCNRInterrogate_RES
+	},
+
+	/*
+	 * globalValue's (OIDs) from CCNR-private-networks-Operations-and-Errors
+	 * {ccitt identified-organization etsi(0) 1065 private-networks-operations-and-errors(2)}
+	 */
+	{
+		ROSE_ETSI_CCNR_T_Request,					&rose_etsi_ccnr_t, 1,
+			rose_enc_etsi_CCNR_T_Request_ARG,		rose_enc_etsi_CCNR_T_Request_RES,
+			rose_dec_etsi_CCNR_T_Request_ARG,		rose_dec_etsi_CCNR_T_Request_RES
+	},
+
+	/*
+	 * localValue's from MCID-Operations
+	 * {ccitt identified-organization etsi(0) 130 operations-and-errors(1)}
+	 */
+	{
+		ROSE_ETSI_MCIDRequest,						NULL, 3,
+			NULL,									NULL,
+			NULL,									NULL
+	},
+
+	/*
+	 * globalValue's (OIDs) from MWI-Operations-and-Errors
+	 * {ccitt identified-organization etsi(0) 745 operations-and-errors(1)}
+	 */
+	{
+		ROSE_ETSI_MWIActivate,						&rose_etsi_mwi, 1,
+			rose_enc_etsi_MWIActivate_ARG,			NULL,
+			rose_dec_etsi_MWIActivate_ARG,			NULL
+	},
+	{
+		ROSE_ETSI_MWIDeactivate,					&rose_etsi_mwi, 2,
+			rose_enc_etsi_MWIDeactivate_ARG,		NULL,
+			rose_dec_etsi_MWIDeactivate_ARG,		NULL
+	},
+	{
+		ROSE_ETSI_MWIIndicate,						&rose_etsi_mwi, 3,
+			rose_enc_etsi_MWIIndicate_ARG,			NULL,
+			rose_dec_etsi_MWIIndicate_ARG,			NULL
+	},
 /* *INDENT-ON* */
 };
 
@@ -463,6 +671,89 @@ static const struct rose_convert_error rose_etsi_errors[] = {
 		ROSE_ERROR_ECT_LinkIdNotAssignedByNetwork,	&rose_etsi_ect, 21,
 			NULL,									NULL
 	},
+
+	/*
+	 * globalValue Errors (OIDs) from CCBS-Operations-and-Errors
+	 * {ccitt identified-organization etsi(0) 359 operations-and-errors(1)}
+	 */
+	{
+		ROSE_ERROR_CCBS_InvalidCallLinkageID,		&rose_etsi_ccbs, 20,
+			NULL,									NULL
+	},
+	{
+		ROSE_ERROR_CCBS_InvalidCCBSReference,		&rose_etsi_ccbs, 21,
+			NULL,									NULL
+	},
+	{
+		ROSE_ERROR_CCBS_LongTermDenial,				&rose_etsi_ccbs, 22,
+			NULL,									NULL
+	},
+	{
+		ROSE_ERROR_CCBS_ShortTermDenial,			&rose_etsi_ccbs, 23,
+			NULL,									NULL
+	},
+	{
+		ROSE_ERROR_CCBS_IsAlreadyActivated,			&rose_etsi_ccbs, 24,
+			NULL,									NULL
+	},
+	{
+		ROSE_ERROR_CCBS_AlreadyAccepted,			&rose_etsi_ccbs, 25,
+			NULL,									NULL
+	},
+	{
+		ROSE_ERROR_CCBS_OutgoingCCBSQueueFull,		&rose_etsi_ccbs, 26,
+			NULL,									NULL
+	},
+	{
+		ROSE_ERROR_CCBS_CallFailureReasonNotBusy,	&rose_etsi_ccbs, 27,
+			NULL,									NULL
+	},
+	{
+		ROSE_ERROR_CCBS_NotReadyForCall,			&rose_etsi_ccbs, 28,
+			NULL,									NULL
+	},
+
+	/*
+	 * globalValue Errors (OIDs) from CCBS-private-networks-Operations-and-Errors
+	 * {ccitt identified-organization etsi(0) 359 private-networks-operations-and-errors(2)}
+	 */
+	{
+		ROSE_ERROR_CCBS_T_LongTermDenial,			&rose_etsi_ccbs_t, 20,
+			NULL,									NULL
+	},
+	{
+		ROSE_ERROR_CCBS_T_ShortTermDenial,			&rose_etsi_ccbs_t, 21,
+			NULL,									NULL
+	},
+
+	/*
+	 * globalValue's (OIDs) from MWI-Operations-and-Errors
+	 * {ccitt identified-organization etsi(0) 745 operations-and-errors(1)}
+	 */
+	{
+		ROSE_ERROR_MWI_InvalidReceivingUserNr,		&rose_etsi_mwi, 10,
+			NULL,									NULL
+	},
+	{
+		ROSE_ERROR_MWI_ReceivingUserNotSubscribed,	&rose_etsi_mwi, 11,
+			NULL,									NULL
+	},
+	{
+		ROSE_ERROR_MWI_ControllingUserNotRegistered,&rose_etsi_mwi, 12,
+			NULL,									NULL
+	},
+	{
+		ROSE_ERROR_MWI_IndicationNotDelivered,		&rose_etsi_mwi, 13,
+			NULL,									NULL
+	},
+	{
+		ROSE_ERROR_MWI_MaxNumOfControllingUsersReached,&rose_etsi_mwi, 14,
+			NULL,									NULL
+	},
+	{
+		ROSE_ERROR_MWI_MaxNumOfActiveInstancesReached,&rose_etsi_mwi, 15,
+			NULL,									NULL
+	},
 /* *INDENT-ON* */
 };
 
@@ -470,6 +761,21 @@ static const struct rose_convert_error rose_etsi_errors[] = {
 /* ------------------------------------------------------------------- */
 
 
+/*
+ * Note the first value in oid.values[] is really the first two
+ * OID subidentifiers.  They are compressed using this formula:
+ * First_Value = (First_Subidentifier * 40) + Second_Subidentifier
+ */
+
+/*! \brief ECMA private-isdn-signalling-domain prefix. */
+static const struct asn1_oid rose_qsig_isdn_domain = {
+/* *INDENT-OFF* */
+	/* {iso(1) identified-organization(3) icd-ecma(12) private-isdn-signalling-domain(9)} */
+	3, { 43, 12, 9 }
+/* *INDENT-ON* */
+};
+
+
 /*! \brief Q.SIG specific invoke/result encode/decode message table */
 static const struct rose_convert_msg rose_qsig_msgs[] = {
 /* *INDENT-OFF* */
@@ -479,7 +785,7 @@ static const struct rose_convert_msg rose_qsig_msgs[] = {
  *			decode_invoke_args,                     decode_result_args
  */
 	/*
-	 * localValue's from Q.SIG Name-Operations
+	 * localValue's from Q.SIG Name-Operations 4th edition
 	 * { iso(1) standard(0) pss1-name(13868) name-operations(0) }
 	 */
 	{
@@ -503,6 +809,34 @@ static const struct rose_convert_msg rose_qsig_msgs[] = {
 			rose_dec_qsig_BusyName_ARG,				NULL
 	},
 
+	/*
+	 * globalValue's (OIDs) from Q.SIG Name-Operations 2nd edition
+	 * { iso(1) identified-organization(3) icd-ecma(12) standard(0) qsig-name(164) name-operations(0) }
+	 *
+	 * This older version of the Q.SIG switch is not supported.
+	 * However, we will accept receiving these messages anyway.
+	 */
+	{
+		ROSE_QSIG_CallingName,						&rose_qsig_isdn_domain, 0,
+			rose_enc_qsig_CallingName_ARG,			NULL,
+			rose_dec_qsig_CallingName_ARG,			NULL
+	},
+	{
+		ROSE_QSIG_CalledName,						&rose_qsig_isdn_domain, 1,
+			rose_enc_qsig_CalledName_ARG,			NULL,
+			rose_dec_qsig_CalledName_ARG,			NULL
+	},
+	{
+		ROSE_QSIG_ConnectedName,					&rose_qsig_isdn_domain, 2,
+			rose_enc_qsig_ConnectedName_ARG,		NULL,
+			rose_dec_qsig_ConnectedName_ARG,		NULL
+	},
+	{
+		ROSE_QSIG_BusyName,							&rose_qsig_isdn_domain, 3,
+			rose_enc_qsig_BusyName_ARG,				NULL,
+			rose_dec_qsig_BusyName_ARG,				NULL
+	},
+
 	/*
 	 * localValue's from Q.SIG SS-AOC-Operations
 	 * { iso(1) standard(0) pss1-advice-of-charge(15050) advice-of-charge-operations(0) }
@@ -649,6 +983,51 @@ static const struct rose_convert_msg rose_qsig_msgs[] = {
 			rose_dec_qsig_DummyArg_ARG,				NULL
 	},
 
+	/*
+	 * localValue's from Q.SIG SS-CC-Operations
+	 * { iso(1) standard(0) pss1-call-completion(13870) operations(0) }
+	 */
+	{
+		ROSE_QSIG_CcbsRequest,						NULL, 40,
+			rose_enc_qsig_CcbsRequest_ARG,			rose_enc_qsig_CcbsRequest_RES,
+			rose_dec_qsig_CcbsRequest_ARG,			rose_dec_qsig_CcbsRequest_RES
+	},
+	{
+		ROSE_QSIG_CcnrRequest,						NULL, 27,
+			rose_enc_qsig_CcnrRequest_ARG,			rose_enc_qsig_CcnrRequest_RES,
+			rose_dec_qsig_CcnrRequest_ARG,			rose_dec_qsig_CcnrRequest_RES
+	},
+	{
+		ROSE_QSIG_CcCancel,							NULL, 28,
+			rose_enq_qsig_CcCancel_ARG,				NULL,
+			rose_dec_qsig_CcCancel_ARG,				NULL
+	},
+	{
+		ROSE_QSIG_CcExecPossible,					NULL, 29,
+			rose_enq_qsig_CcExecPossible_ARG,		NULL,
+			rose_dec_qsig_CcExecPossible_ARG,		NULL
+	},
+	{
+		ROSE_QSIG_CcPathReserve,					NULL, 30,
+			rose_enc_qsig_CcPathReserve_ARG,		rose_enc_qsig_CcPathReserve_RES,
+			rose_dec_qsig_CcPathReserve_ARG,		rose_dec_qsig_CcPathReserve_RES
+	},
+	{
+		ROSE_QSIG_CcRingout,						NULL, 31,
+			rose_enc_qsig_CcRingout_ARG,			NULL,
+			rose_dec_qsig_CcRingout_ARG,			NULL
+	},
+	{
+		ROSE_QSIG_CcSuspend,						NULL, 32,
+			rose_enc_qsig_CcSuspend_ARG,			NULL,
+			rose_dec_qsig_CcSuspend_ARG,			NULL
+	},
+	{
+		ROSE_QSIG_CcResume,							NULL, 33,
+			rose_enc_qsig_CcResume_ARG,				NULL,
+			rose_dec_qsig_CcResume_ARG,				NULL
+	},
+
 	/*
 	 * localValue's from Q.SIG SS-MWI-Operations
 	 * { iso(1) standard(0) pss1-message-waiting-indication(15506) message-waiting-operations(0) }
@@ -800,6 +1179,31 @@ static const struct rose_convert_error rose_qsig_errors[] = {
 			NULL,									NULL
 	},
 
+	/*
+	 * localValue's from Q.SIG SS-CC-Operations
+	 * { iso(1) standard(0) pss1-call-completion(13870) operations(0) }
+	 */
+	{
+		ROSE_ERROR_QSIG_ShortTermRejection,			NULL, 1010,
+			NULL,									NULL
+	},
+	{
+		ROSE_ERROR_QSIG_LongTermRejection,			NULL, 1011,
+			NULL,									NULL
+	},
+	{
+		ROSE_ERROR_QSIG_RemoteUserBusyAgain,		NULL, 1012,
+			NULL,									NULL
+	},
+	{
+		ROSE_ERROR_QSIG_FailureToMatch,				NULL, 1013,
+			NULL,									NULL
+	},
+	{
+		ROSE_ERROR_QSIG_FailedDueToInterworking,	NULL, 1014,
+			NULL,									NULL
+	},
+
 	/*
 	 * localValue's from Q.SIG SS-MWI-Operations
 	 * { iso(1) standard(0) pss1-message-waiting-indication(15506) message-waiting-operations(0) }
@@ -833,6 +1237,34 @@ static const struct rose_convert_msg rose_dms100_msgs[] = {
 			rose_enc_dms100_RLT_ThirdParty_ARG,		NULL,
 			rose_dec_dms100_RLT_ThirdParty_ARG,		NULL
 	},
+
+	/* DMS-100 seems to have pirated some Q.SIG messages */
+	/*
+	 * localValue's from Q.SIG Name-Operations
+	 * { iso(1) standard(0) pss1-name(13868) name-operations(0) }
+	 */
+	{
+		ROSE_QSIG_CallingName,						NULL, 0,
+			rose_enc_qsig_CallingName_ARG,			NULL,
+			rose_dec_qsig_CallingName_ARG,			NULL
+	},
+#if 0	/* ROSE_DMS100_RLT_OPERATION_IND, and ROSE_DMS100_RLT_THIRD_PARTY conflict! */
+	{
+		ROSE_QSIG_CalledName,						NULL, 1,
+			rose_enc_qsig_CalledName_ARG,			NULL,
+			rose_dec_qsig_CalledName_ARG,			NULL
+	},
+	{
+		ROSE_QSIG_ConnectedName,					NULL, 2,
+			rose_enc_qsig_ConnectedName_ARG,		NULL,
+			rose_dec_qsig_ConnectedName_ARG,		NULL
+	},
+	{
+		ROSE_QSIG_BusyName,							NULL, 3,
+			rose_enc_qsig_BusyName_ARG,				NULL,
+			rose_dec_qsig_BusyName_ARG,				NULL
+	},
+#endif
 /* *INDENT-ON* */
 };
 
@@ -888,6 +1320,19 @@ static const struct rose_convert_msg rose_ni2_msgs[] = {
  *			encode_invoke_args,                     encode_result_args,
  *			decode_invoke_args,                     decode_result_args
  */
+	{
+		ROSE_NI2_InformationFollowing,				&rose_ni2_oid, 4,
+			rose_enc_ni2_InformationFollowing_ARG,	NULL,
+			rose_dec_ni2_InformationFollowing_ARG,	NULL
+	},
+
+	/* Also used by PRI_SWITCH_ATT4ESS and PRI_SWITCH_LUCENT5E */
+	{
+		ROSE_NI2_InitiateTransfer,					&rose_ni2_oid, 8,
+			rose_enc_ni2_InitiateTransfer_ARG,		NULL,
+			rose_dec_ni2_InitiateTransfer_ARG,		NULL
+	},
+
 	/* NI2 seems to have pirated several Q.SIG messages */
 	/*
 	 * localValue's from Q.SIG Name-Operations
@@ -913,19 +1358,6 @@ static const struct rose_convert_msg rose_ni2_msgs[] = {
 			rose_enc_qsig_BusyName_ARG,				NULL,
 			rose_dec_qsig_BusyName_ARG,				NULL
 	},
-
-	{
-		ROSE_NI2_InformationFollowing,				&rose_ni2_oid, 4,
-			rose_enc_ni2_InformationFollowing_ARG,	NULL,
-			rose_dec_ni2_InformationFollowing_ARG,	NULL
-	},
-
-	/* Also used by PRI_SWITCH_ATT4ESS and PRI_SWITCH_LUCENT5E */
-	{
-		ROSE_NI2_InitiateTransfer,					&rose_ni2_oid, 8,
-			rose_enc_ni2_InitiateTransfer_ARG,		NULL,
-			rose_dec_ni2_InitiateTransfer_ARG,		NULL
-	},
 /* *INDENT-ON* */
 };
 
@@ -1069,6 +1501,40 @@ const char *rose_operation2str(enum rose_operation operation)
 		{ ROSE_ETSI_AOCECurrency,                   "ROSE_ETSI_AOCECurrency" },
 		{ ROSE_ETSI_AOCEChargingUnit,               "ROSE_ETSI_AOCEChargingUnit" },
 
+		{ ROSE_ETSI_StatusRequest,                  "ROSE_ETSI_StatusRequest" },
+
+		{ ROSE_ETSI_CallInfoRetain,                 "ROSE_ETSI_CallInfoRetain" },
+		{ ROSE_ETSI_EraseCallLinkageID,             "ROSE_ETSI_EraseCallLinkageID" },
+		{ ROSE_ETSI_CCBSDeactivate,                 "ROSE_ETSI_CCBSDeactivate" },
+		{ ROSE_ETSI_CCBSErase,                      "ROSE_ETSI_CCBSErase" },
+		{ ROSE_ETSI_CCBSRemoteUserFree,             "ROSE_ETSI_CCBSRemoteUserFree" },
+		{ ROSE_ETSI_CCBSCall,                       "ROSE_ETSI_CCBSCall" },
+		{ ROSE_ETSI_CCBSStatusRequest,              "ROSE_ETSI_CCBSStatusRequest" },
+		{ ROSE_ETSI_CCBSBFree,                      "ROSE_ETSI_CCBSBFree" },
+		{ ROSE_ETSI_CCBSStopAlerting,               "ROSE_ETSI_CCBSStopAlerting" },
+
+		{ ROSE_ETSI_CCBSRequest,                    "ROSE_ETSI_CCBSRequest" },
+		{ ROSE_ETSI_CCBSInterrogate,                "ROSE_ETSI_CCBSInterrogate" },
+
+		{ ROSE_ETSI_CCNRRequest,                    "ROSE_ETSI_CCNRRequest" },
+		{ ROSE_ETSI_CCNRInterrogate,                "ROSE_ETSI_CCNRInterrogate" },
+
+		{ ROSE_ETSI_CCBS_T_Call,                    "ROSE_ETSI_CCBS_T_Call" },
+		{ ROSE_ETSI_CCBS_T_Suspend,                 "ROSE_ETSI_CCBS_T_Suspend" },
+		{ ROSE_ETSI_CCBS_T_Resume,                  "ROSE_ETSI_CCBS_T_Resume" },
+		{ ROSE_ETSI_CCBS_T_RemoteUserFree,          "ROSE_ETSI_CCBS_T_RemoteUserFree" },
+		{ ROSE_ETSI_CCBS_T_Available,               "ROSE_ETSI_CCBS_T_Available" },
+
+		{ ROSE_ETSI_CCBS_T_Request,                 "ROSE_ETSI_CCBS_T_Request" },
+
+		{ ROSE_ETSI_CCNR_T_Request,                 "ROSE_ETSI_CCNR_T_Request" },
+
+		{ ROSE_ETSI_MCIDRequest,                    "ROSE_ETSI_MCIDRequest" },
+
+		{ ROSE_ETSI_MWIActivate,                    "ROSE_ETSI_MWIActivate" },
+		{ ROSE_ETSI_MWIDeactivate,                  "ROSE_ETSI_MWIDeactivate" },
+		{ ROSE_ETSI_MWIIndicate,                    "ROSE_ETSI_MWIIndicate" },
+
 		{ ROSE_QSIG_CallingName,                    "ROSE_QSIG_CallingName" },
 		{ ROSE_QSIG_CalledName,                     "ROSE_QSIG_CalledName" },
 		{ ROSE_QSIG_ConnectedName,                  "ROSE_QSIG_ConnectedName" },
@@ -1103,6 +1569,15 @@ const char *rose_operation2str(enum rose_operation operation)
 		{ ROSE_QSIG_DivertingLegInformation3,       "ROSE_QSIG_DivertingLegInformation3" },
 		{ ROSE_QSIG_CfnrDivertedLegFailed,          "ROSE_QSIG_CfnrDivertedLegFailed" },
 
+		{ ROSE_QSIG_CcbsRequest,                    "ROSE_QSIG_CcbsRequest" },
+		{ ROSE_QSIG_CcnrRequest,                    "ROSE_QSIG_CcnrRequest" },
+		{ ROSE_QSIG_CcCancel,                       "ROSE_QSIG_CcCancel" },
+		{ ROSE_QSIG_CcExecPossible,                 "ROSE_QSIG_CcExecPossible" },
+		{ ROSE_QSIG_CcPathReserve,                  "ROSE_QSIG_CcPathReserve" },
+		{ ROSE_QSIG_CcRingout,                      "ROSE_QSIG_CcRingout" },
+		{ ROSE_QSIG_CcSuspend,                      "ROSE_QSIG_CcSuspend" },
+		{ ROSE_QSIG_CcResume,                       "ROSE_QSIG_CcResume" },
+
 		{ ROSE_QSIG_MWIActivate,                    "ROSE_QSIG_MWIActivate" },
 		{ ROSE_QSIG_MWIDeactivate,                  "ROSE_QSIG_MWIDeactivate" },
 		{ ROSE_QSIG_MWIInterrogate,                 "ROSE_QSIG_MWIInterrogate" },
@@ -1161,6 +1636,26 @@ const char *rose_error2str(enum rose_error_code code)
 
 		{ ROSE_ERROR_ECT_LinkIdNotAssignedByNetwork,  "ECT: Link ID Not Assigned By Network" },
 
+		{ ROSE_ERROR_CCBS_InvalidCallLinkageID,       "CCBS: Invalid Call Linkage ID" },
+		{ ROSE_ERROR_CCBS_InvalidCCBSReference,       "CCBS: Invalid CCBS Reference" },
+		{ ROSE_ERROR_CCBS_LongTermDenial,             "CCBS: Long Term Denial" },
+		{ ROSE_ERROR_CCBS_ShortTermDenial,            "CCBS: Short Term Denial" },
+		{ ROSE_ERROR_CCBS_IsAlreadyActivated,         "CCBS: Is Already Activated" },
+		{ ROSE_ERROR_CCBS_AlreadyAccepted,            "CCBS: Already Accepted" },
+		{ ROSE_ERROR_CCBS_OutgoingCCBSQueueFull,      "CCBS: Outgoing CCBS Queue Full" },
+		{ ROSE_ERROR_CCBS_CallFailureReasonNotBusy,   "CCBS: Call Failure Reason Not Busy" },
+		{ ROSE_ERROR_CCBS_NotReadyForCall,            "CCBS: Not Ready For Call" },
+
+		{ ROSE_ERROR_CCBS_T_LongTermDenial,           "CCBS-T: Long Term Denial" },
+		{ ROSE_ERROR_CCBS_T_ShortTermDenial,          "CCBS-T: Short Term Denial" },
+
+		{ ROSE_ERROR_MWI_InvalidReceivingUserNr,      "MWI: Invalid Receiving User Number" },
+		{ ROSE_ERROR_MWI_ReceivingUserNotSubscribed,  "MWI: Receiving User Not Subscribed" },
+		{ ROSE_ERROR_MWI_ControllingUserNotRegistered,"MWI: Controlling User Not Registered" },
+		{ ROSE_ERROR_MWI_IndicationNotDelivered,      "MWI: Indication Not Delivered" },
+		{ ROSE_ERROR_MWI_MaxNumOfControllingUsersReached,"MWI: Max Num Of Controlling Users Reached" },
+		{ ROSE_ERROR_MWI_MaxNumOfActiveInstancesReached,"MWI: Max Num Of Active Instances Reached" },
+
 		/* Q.SIG specific errors */
 		{ ROSE_ERROR_QSIG_Unspecified,                "Unspecified" },
 
@@ -1173,6 +1668,12 @@ const char *rose_error2str(enum rose_error_code code)
 		{ ROSE_ERROR_QSIG_Div_TemporarilyUnavailable, "Diversion: Temporarily Unavailable" },
 		{ ROSE_ERROR_QSIG_Div_NotAuthorized,          "Diversion: Not Authorized" },
 
+		{ ROSE_ERROR_QSIG_ShortTermRejection,         "CC: Short Term Rejection" },
+		{ ROSE_ERROR_QSIG_LongTermRejection,          "CC: Long Term Rejection" },
+		{ ROSE_ERROR_QSIG_RemoteUserBusyAgain,        "CC: Remote User Busy Again" },
+		{ ROSE_ERROR_QSIG_FailureToMatch,             "CC: Failure To Match" },
+		{ ROSE_ERROR_QSIG_FailedDueToInterworking,    "CC: Failed Due To Interworking" },
+
 		{ ROSE_ERROR_QSIG_InvalidMsgCentreId,         "MWI: Invalid Message Center ID" },
 
 		/* DMS-100 specific errors */
